==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkPieChartActor.java <==
// java wrapper for vtkPieChartActor object
//

package vtk;
import vtk.*;

public class vtkPieChartActor extends vtkActor2D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_2(id0); }

  private native void SetInputConnection_3(vtkAlgorithmOutput id0);
  public void SetInputConnection(vtkAlgorithmOutput id0)
    { SetInputConnection_3(id0); }

  private native long GetInput_4();
  public vtkDataObject GetInput() {
    long temp = GetInput_4();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTitleVisibility_5(int id0);
  public void SetTitleVisibility(int id0)
    { SetTitleVisibility_5(id0); }

  private native int GetTitleVisibility_6();
  public int GetTitleVisibility()
    { return GetTitleVisibility_6(); }

  private native void TitleVisibilityOn_7();
  public void TitleVisibilityOn()
    { TitleVisibilityOn_7(); }

  private native void TitleVisibilityOff_8();
  public void TitleVisibilityOff()
    { TitleVisibilityOff_8(); }

  private native void SetTitle_9(String id0);
  public void SetTitle(String id0)
    { SetTitle_9(id0); }

  private native String GetTitle_10();
  public String GetTitle()
    { return GetTitle_10(); }

  private native void SetTitleTextProperty_11(vtkTextProperty id0);
  public void SetTitleTextProperty(vtkTextProperty id0)
    { SetTitleTextProperty_11(id0); }

  private native long GetTitleTextProperty_12();
  public vtkTextProperty GetTitleTextProperty() {
    long temp = GetTitleTextProperty_12();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelVisibility_13(int id0);
  public void SetLabelVisibility(int id0)
    { SetLabelVisibility_13(id0); }

  private native int GetLabelVisibility_14();
  public int GetLabelVisibility()
    { return GetLabelVisibility_14(); }

  private native void LabelVisibilityOn_15();
  public void LabelVisibilityOn()
    { LabelVisibilityOn_15(); }

  private native void LabelVisibilityOff_16();
  public void LabelVisibilityOff()
    { LabelVisibilityOff_16(); }

  private native void SetLabelTextProperty_17(vtkTextProperty id0);
  public void SetLabelTextProperty(vtkTextProperty id0)
    { SetLabelTextProperty_17(id0); }

  private native long GetLabelTextProperty_18();
  public vtkTextProperty GetLabelTextProperty() {
    long temp = GetLabelTextProperty_18();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPieceColor_19(int id0,double id1,double id2,double id3);
  public void SetPieceColor(int id0,double id1,double id2,double id3)
    { SetPieceColor_19(id0,id1,id2,id3); }

  private native void SetPieceColor_20(int id0,double id1[]);
  public void SetPieceColor(int id0,double id1[])
    { SetPieceColor_20(id0,id1); }

  private native void SetPieceLabel_21(int id0,String id1);
  public void SetPieceLabel(int id0,String id1)
    { SetPieceLabel_21(id0,id1); }

  private native String GetPieceLabel_22(int id0);
  public String GetPieceLabel(int id0)
    { return GetPieceLabel_22(id0); }

  private native void SetLegendVisibility_23(int id0);
  public void SetLegendVisibility(int id0)
    { SetLegendVisibility_23(id0); }

  private native int GetLegendVisibility_24();
  public int GetLegendVisibility()
    { return GetLegendVisibility_24(); }

  private native void LegendVisibilityOn_25();
  public void LegendVisibilityOn()
    { LegendVisibilityOn_25(); }

  private native void LegendVisibilityOff_26();
  public void LegendVisibilityOff()
    { LegendVisibilityOff_26(); }

  private native long GetLegendActor_27();
  public vtkLegendBoxActor GetLegendActor() {
    long temp = GetLegendActor_27();

    if (temp == 0) return null;
    return (vtkLegendBoxActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int RenderOverlay_28(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_28(id0); }

  private native int RenderOpaqueGeometry_29(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_29(id0); }

  private native int RenderTranslucentPolygonalGeometry_30(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_30(id0); }

  private native int HasTranslucentPolygonalGeometry_31();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_31(); }

  private native void ReleaseGraphicsResources_32(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_32(id0); }

  public vtkPieChartActor() { super(); }

  public vtkPieChartActor(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkPieChartActor.java <==
// java wrapper for vtkPieChartActor object
//

package vtk;
import vtk.*;

public class vtkPieChartActor extends vtkActor2D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_2(id0); }

  private native void SetInputConnection_3(vtkAlgorithmOutput id0);
  public void SetInputConnection(vtkAlgorithmOutput id0)
    { SetInputConnection_3(id0); }

  private native long GetInput_4();
  public vtkDataObject GetInput() {
    long temp = GetInput_4();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTitleVisibility_5(int id0);
  public void SetTitleVisibility(int id0)
    { SetTitleVisibility_5(id0); }

  private native int GetTitleVisibility_6();
  public int GetTitleVisibility()
    { return GetTitleVisibility_6(); }

  private native void TitleVisibilityOn_7();
  public void TitleVisibilityOn()
    { TitleVisibilityOn_7(); }

  private native void TitleVisibilityOff_8();
  public void TitleVisibilityOff()
    { TitleVisibilityOff_8(); }

  private native void SetTitle_9(String id0);
  public void SetTitle(String id0)
    { SetTitle_9(id0); }

  private native String GetTitle_10();
  public String GetTitle()
    { return GetTitle_10(); }

  private native void SetTitleTextProperty_11(vtkTextProperty id0);
  public void SetTitleTextProperty(vtkTextProperty id0)
    { SetTitleTextProperty_11(id0); }

  private native long GetTitleTextProperty_12();
  public vtkTextProperty GetTitleTextProperty() {
    long temp = GetTitleTextProperty_12();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelVisibility_13(int id0);
  public void SetLabelVisibility(int id0)
    { SetLabelVisibility_13(id0); }

  private native int GetLabelVisibility_14();
  public int GetLabelVisibility()
    { return GetLabelVisibility_14(); }

  private native void LabelVisibilityOn_15();
  public void LabelVisibilityOn()
    { LabelVisibilityOn_15(); }

  private native void LabelVisibilityOff_16();
  public void LabelVisibilityOff()
    { LabelVisibilityOff_16(); }

  private native void SetLabelTextProperty_17(vtkTextProperty id0);
  public void SetLabelTextProperty(vtkTextProperty id0)
    { SetLabelTextProperty_17(id0); }

  private native long GetLabelTextProperty_18();
  public vtkTextProperty GetLabelTextProperty() {
    long temp = GetLabelTextProperty_18();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPieceColor_19(int id0,double id1,double id2,double id3);
  public void SetPieceColor(int id0,double id1,double id2,double id3)
    { SetPieceColor_19(id0,id1,id2,id3); }

  private native void SetPieceColor_20(int id0,double id1[]);
  public void SetPieceColor(int id0,double id1[])
    { SetPieceColor_20(id0,id1); }

  private native void SetPieceLabel_21(int id0,String id1);
  public void SetPieceLabel(int id0,String id1)
    { SetPieceLabel_21(id0,id1); }

  private native String GetPieceLabel_22(int id0);
  public String GetPieceLabel(int id0)
    { return GetPieceLabel_22(id0); }

  private native void SetLegendVisibility_23(int id0);
  public void SetLegendVisibility(int id0)
    { SetLegendVisibility_23(id0); }

  private native int GetLegendVisibility_24();
  public int GetLegendVisibility()
    { return GetLegendVisibility_24(); }

  private native void LegendVisibilityOn_25();
  public void LegendVisibilityOn()
    { LegendVisibilityOn_25(); }

  private native void LegendVisibilityOff_26();
  public void LegendVisibilityOff()
    { LegendVisibilityOff_26(); }

  private native long GetLegendActor_27();
  public vtkLegendBoxActor GetLegendActor() {
    long temp = GetLegendActor_27();

    if (temp == 0) return null;
    return (vtkLegendBoxActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int RenderOverlay_28(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_28(id0); }

  private native int RenderOpaqueGeometry_29(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_29(id0); }

  private native int RenderTranslucentPolygonalGeometry_30(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_30(id0); }

  private native int HasTranslucentPolygonalGeometry_31();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_31(); }

  private native void ReleaseGraphicsResources_32(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_32(id0); }

  public vtkPieChartActor() { super(); }

  public vtkPieChartActor(long id) { super(id); }
  public native long   VTKInit();

}
